@@ -1,11 +1,10 @@
 mod utils;
 
-use utils::{Timezone, format_time, format_path};
-
+use utils::{format_time, format_path};
 use log::{Level, LevelFilter, Log, Metadata, Record, SetLoggerError};
-
 use ansi_term::Color;
 
+pub use utils::{Timezone};
 
 static LOG_LEVEL_NAMES: [&str; 6] = ["N/A", "E", "W", "I", "D", "T"];
 
